Welcome to ClientVPS Mirrors

Help for package gghalfnorm
Type: Package
Title: Create a Half Normal Plot Using 'ggplot2'
Version: 1.1.2
Description: Reproduce the halfnorm() function found in the 'faraway' package using the 'ggplot2' API.
URL: https://github.com/nathaneastwood/gghalfnorm
BugReports: https://github.com/nathaneastwood/gghalfnorm/issues
Depends: R (≥ 3.1.0)
Imports: ggplot2 (≥ 2.0.0), ggrepel (≥ 0.6.5)
License: AGPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
Suggests: covr, testthat
NeedsCompilation: no
Packaged: 2017-06-06 10:44:32 UTC; eastn
Author: Nathan Eastwood [aut, cre]
Maintainer: Nathan Eastwood <nathan.eastwood@icloud.com>
Repository: CRAN
Date/Publication: 2017-06-06 11:29:50 UTC

Half Normal Plot

Description

Produce a Half Normal Plot for a vector of residuals.

Usage

gghalfnorm(x, nlab = 2, labs = as.character(seq_along(x)), repel = FALSE,
  ...)

Arguments

x

A vector of residuals.

nlab

The number of points to label.

labs

The labels for the points.

repel

Logical. Whether to repel the labels or not.

...

Additional parameters to be passed to geom_text_repel.

See Also

qqnorm

Examples

set.seed(100)
gghalfnorm(x = rnorm(100), nlab = 10)
gghalfnorm(x = rnorm(100), nlab = 10, repel = TRUE)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.